@@ -32,11 +32,10 @@ class QLabel;
 #include <QVBoxLayout>
 class QPushButton;
 #include <QTimer>
-class KTabWidget;
+class QTabWidget;
 
 // KDE
 class KAccel;
-class KAction;
 class KToggleAction;
 #include <kxmlguiwindow.h>
 
@@ -49,9 +48,6 @@ class KMixWindow;
 class Mixer;
 #include "core/mixer.h"
 
-#ifndef X_KMIX_KF5_BUILD
-class OSDWidget;
-#endif
 class DialogSelectMaster;
 
 class
@@ -77,7 +73,7 @@ KMixWindow : public KXmlGuiWindow
 
    void fixConfigAfterRead();
 
-   virtual bool queryClose();
+   bool queryClose() Q_DECL_OVERRIDE;
 
   public slots:
    void controlsChange(int changeType);
@@ -102,7 +98,6 @@ KMixWindow : public KXmlGuiWindow
         KMixerWidget* findKMWforTab( const QString& tabId );
 
         void forkExec(const QStringList& args);
-        void errorPopup(const QString& msg);
 
    KAccel *m_keyAccel;
    KToggleAction* _actionShowMenubar;
@@ -118,7 +113,7 @@ private:
    bool m_multiDriverMode;         // Not officially supported.
    bool m_autouseMultimediaKeys;   // Due to message freeze, not in config dialog in KDE4.4
 
-   KTabWidget *m_wsMixers;
+   QTabWidget *m_wsMixers;
 
    KMixDockWidget *m_dockWidget;
    DialogSelectMaster *m_dsm;
@@ -132,10 +127,6 @@ private:
    void showVolumeDisplay();
    void increaseOrDecreaseVolume(bool increase);
 
-#ifndef X_KMIX_KF5_BUILD
-   OSDWidget* osdWidget;
-#endif
-
    bool addMixerWidget(const QString& mixer_ID, QString guiprofId, int insertPosition);
    void setInitialSize();
 
