@@ -46,11 +46,10 @@
 
 
 // KDE
-#include <kdebug.h>
-#include <KIcon>
-#include <KLocale>
+#include <klocalizedstring.h>
 
 // Qt
+#include <QIcon>
 #include <QPushButton>
 #include <QLabel>
 #include <QLayoutItem>
@@ -103,7 +102,7 @@ void ViewSliders::controlsChange(int changeType)
 
 	case ControlChangeType::Volume:
 		if (GlobalConfig::instance().data.debugVolume)
-			kDebug()
+			qCDebug(KMIX_LOG)
 			<< "NOW I WILL REFRESH VOLUME LEVELS. I AM " << id();
 		refreshVolumeLevels();
 		break;
@@ -215,7 +214,13 @@ void ViewSliders::_setMixSet()
 	_layoutSliders->setSpacing(0);
 	_layoutMDW->setContentsMargins(0, 0, 0, 0);
 	_layoutMDW->setSpacing(0);
+
+	// The stretch added here is so that, if there is width to spare, the
+	// controls are centered in the window but the configure button is
+	// always at the bottom right.
+	_layoutMDW->addStretch();
 	_layoutMDW->addItem(_layoutSliders);
+	_layoutMDW->addStretch();
 
 	_layoutEnum = new QVBoxLayout();
 	_layoutMDW->addLayout(_layoutEnum);
@@ -259,7 +264,7 @@ void ViewSliders::_setMixSet()
 			QRegExp idRegexp(control->id);
 			//bool isExactRegexp = control->id.startsWith('^') && control->id.endsWith('$'); // for optimizing
 			//isExactRegexp &= ( ! control->id.contains(".*") ); // For now. Might be removed in the future, as it cannot be done properly !!!
-			//kDebug(67100) << "ViewSliders::setMixSet(): Check GUIProfile id==" << control->id << "\n";
+			//qCDebug(KMIX_LOG) << "ViewSliders::setMixSet(): Check GUIProfile id==" << control->id << "\n";
 			// The following for-loop could be simplified by using a std::find_if
 			for ( int i=0; i<mixset.count(); i++ )
 			{
@@ -356,7 +361,7 @@ void ViewSliders::configurationUpdate()
 		if (mdw && mdw->isVisibleTo(this))
 		{
 			labelExtent = qMax(labelExtent, mdw->labelExtentHint());
-			//kDebug() << "########## EXTENT for " << id() << " is " << labelExtent;
+			//qCDebug(KMIX_LOG) << "########## EXTENT for " << id() << " is " << labelExtent;
 			haveCaptureLEDs = haveCaptureLEDs || mdw->hasCaptureLED();
 			haveMuteButtons = haveMuteButtons || mdw->hasMuteButton();
 		}
@@ -365,7 +370,7 @@ void ViewSliders::configurationUpdate()
 		//		if (haveCaptureLEDs && haveMuteButtons)
 		//			break; // We know all we want. Lets break.
 	}
-   //kDebug(67100) << "topPartExtent is " << topPartExtent;
+   //qCDebug(KMIX_LOG) << "topPartExtent is " << topPartExtent;
    bool firstVisibleControlFound = false;
    for ( int i=0; i<_mdws.count(); i++ )
    {
@@ -425,7 +430,7 @@ void ViewSliders::refreshVolumeLevels()
 			{
 				bool debugMe = (mdw->mixDevice()->id() == "PCM:0");
 				if (debugMe)
-					kDebug()
+					qCDebug(KMIX_LOG)
 					<< "Old PCM:0 playback state" << mdw->mixDevice()->isMuted() << ", vol="
 						<< mdw->mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
 			}
@@ -434,7 +439,7 @@ void ViewSliders::refreshVolumeLevels()
 		}
 		else
 		{
-			kError(67100) << "ViewSliders::refreshVolumeLevels(): mdw is not a MixDeviceWidget\n";
+			qCCritical(KMIX_LOG) << "ViewSliders::refreshVolumeLevels(): mdw is not a MixDeviceWidget\n";
 			// no slider. Cannot happen in theory => skip it
 		}
 	}
